label property

String get label

Returns a human-readable label for each barcode type.

These labels are appropriate for displaying to users in the UI and use the standard naming conventions for each barcode format.

Implementation

String get label {
  switch (this) {
    case QrBarType.qr:
      return 'QR Code';
    case QrBarType.c128:
      return 'Code 128';
    case QrBarType.ean13:
      return 'EAN-13';
    case QrBarType.upc:
      return 'UPC';
    case QrBarType.pdf417:
      return 'PDF417';
    case QrBarType.aztec:
      return 'Aztec';
    case QrBarType.dm:
      return 'Data Matrix';
  }
}