shadowOffset property

Offset shadowOffset
final

Optional shadow offset for the shadow style.

Controls the position of the shadow relative to the QR code when using QrStyle.shadow. Positive values place the shadow down and to the right.

Default is Offset(2.0, 2.0). Only used when style is QrStyle.shadow.

Implementation

final Offset shadowOffset;