tertiaryColor property
Optional tertiary color for styles that use multiple colors.
Currently used primarily in the pixelArt style to create a more distinctive retro aesthetic with three different colors.
Implementation
final Color? tertiaryColor;
Optional tertiary color for styles that use multiple colors.
Currently used primarily in the pixelArt style to create a more distinctive retro aesthetic with three different colors.
final Color? tertiaryColor;