label property
String
get
label
Returns a human-readable label for each QR style.
These labels are appropriate for displaying to users in the UI and use clear terminology to describe each visual style.
Implementation
String get label {
switch (this) {
case QrStyle.standard:
return 'Standard';
case QrStyle.rounded:
return 'Rounded';
case QrStyle.withLogo:
return 'With Logo';
case QrStyle.gradient:
return 'Gradient';
case QrStyle.fancyEyes:
return 'Fancy Eyes';
case QrStyle.dots:
return 'Dots';
case QrStyle.framed:
return 'Framed';
case QrStyle.shadow:
return 'Shadow';
case QrStyle.mosaic:
return 'Mosaic';
case QrStyle.pixelArt:
return 'Pixel Art';
}
}